@@ -2,10 +2,10 @@
 BEAST Fitting functions
 """
 import numpy as np
-import math
 import tables
 import string
 from itertools import islice
+import warnings
 
 import numexpr
 
@@ -17,13 +17,12 @@ from astropy.table import Table
 from tqdm import tqdm
 
 from beast.physicsmodel import grid
-
+from beast.tools.symlog import symlog
 from beast.fitting.fit_metrics.likelihood import (
     N_covar_logLikelihood,
     N_logLikelihood_NM,
 )
 from beast.fitting.fit_metrics import expectation, percentile
-
 from beast.fitting.pdf1d import pdf1d
 from beast.fitting.pdf2d import pdf2d
 
@@ -51,6 +50,8 @@ def save_stats(
     total_log_norm,
     qnames,
     p,
+    filters,
+    wavelengths,
 ):
     """
     Save various fitting statistics to a file
@@ -108,7 +109,19 @@ def save_stats(
     summary_tab = Table(stats_dict)
 
     if stats_outname is not None:
-        summary_tab.write(stats_outname, overwrite=True)
+        # standard Table writing of FITS files does not support multiple extensions
+        # but reading does, so only have to do this when writing
+        ohdu = fits.HDUList()
+        ohdu.append(fits.table_to_hdu(summary_tab))
+
+        # create a table with the filter names and wavelengths
+        # useful for plotting the results
+        filters_tab = Table()
+        filters_tab["filternames"] = filters
+        filters_tab["wavelengths"] = wavelengths
+        ohdu.append(fits.table_to_hdu(filters_tab))
+
+        ohdu.writeto(stats_outname, overwrite=True)
 
 
 def save_pdf1d(pdf1d_outname, save_pdf1d_vals, qnames):
@@ -229,7 +242,7 @@ def setup_param_bins(qname, max_nbins, g0, full_model_flux, filters, grid_info_d
         name of the parameter
     max_nbins : int
         max number of bins to use for the PDF calculations
-    g0 : FileSEDGrid object
+    g0 : SEDGrid object
         the SED grid
     full_model_flux : ndarray
         1D `float` array of the fluxes for the model grid
@@ -262,8 +275,10 @@ def setup_param_bins(qname, max_nbins, g0, full_model_flux, filters, grid_info_d
         # unique values across all the subgrids to make the 1dpdfs
         # compatible
         n_uniq = grid_info_dict[qname]["num_unique"]
+        uniqvals = grid_info_dict[qname]["unique_vals"]
     else:
-        n_uniq = len(np.unique(qname_vals))
+        uniqvals = np.unique(qname_vals)
+        n_uniq = len(uniqvals)
 
     if n_uniq > max_nbins:
         # limit the number of bins in the 1D likelihood for speed
@@ -272,8 +287,8 @@ def setup_param_bins(qname, max_nbins, g0, full_model_flux, filters, grid_info_d
         nbins = n_uniq
 
     # temp code for BEAST paper figure
-    if qname == "Z":
-        nbins = nbins + 1
+    # if qname == "Z":
+    #     nbins = nbins + 1
 
     # setup for the fast 1D/2D PDFs
 
@@ -291,7 +306,7 @@ def setup_param_bins(qname, max_nbins, g0, full_model_flux, filters, grid_info_d
         minval = None
         maxval = None
 
-    return qname_vals, nbins, logspacing, minval, maxval
+    return qname_vals, nbins, logspacing, minval, maxval, uniqvals
 
 
 def Q_all_memory(
@@ -302,7 +317,7 @@ def Q_all_memory(
     qnames_in,
     p=[16.0, 50.0, 84.0],
     gridbackend="cache",
-    max_nbins=50,
+    max_nbins=200,
     stats_outname=None,
     pdf1d_outname=None,
     pdf2d_outname=None,
@@ -338,7 +353,7 @@ def Q_all_memory(
     gridbackend : str or grid.GridBackend
         backend to use to load the grid if necessary (memory, cache, hdf)
         (see beast.core.grid)
-    max_nbins : int
+    max_nbins : int (default=200)
         maxiumum number of bins to use for the 1D likelihood calculations
     save_every_npts : int
         set to save the files below (if set) every n stars
@@ -378,22 +393,29 @@ def Q_all_memory(
     """
 
     if type(sedgrid) == str:
-        g0 = grid.FileSEDGrid(sedgrid, backend=gridbackend)
+        g0 = grid.SEDGrid(sedgrid, backend=gridbackend)
     else:
         g0 = sedgrid
 
     # remove weights that are less than zero
     (g0_indxs,) = np.where(g0["weight"] > 0.0)
 
+    for i, cfilter in enumerate(sedgrid.filters):
+        (incomp_indxs,) = np.where(obsmodel["completeness"][:, i] <= 0.0)
+        if len(incomp_indxs) > 0:
+            raise ValueError(
+                "models with zero completeness present in the observation model"
+            )
+
     g0_weights = np.log(g0["weight"][g0_indxs])
     if not do_not_normalize:
         # this variable used on the next line, so is used regardless of what flake8 says
-        g0_weights_sum = np.log(g0["weight"][g0_indxs].sum())  # noqa: E302
+        g0_weights_sum = np.log(g0["weight"][g0_indxs].sum())  # noqa: F841
         g0_weights = numexpr.evaluate("g0_weights - g0_weights_sum")
 
     if len(g0["weight"]) != len(g0_indxs):
-        print("some zero weight models exist")
-        print("orig/g0_indxs", len(g0["weight"]), len(g0_indxs))
+        warnings.warn("some zero weight models exist")
+        warnings.warn("orig/g0_indxs", len(g0["weight"]), len(g0_indxs))
 
     # get the model SEDs
     if hasattr(g0.seds, "read"):
@@ -439,11 +461,7 @@ def Q_all_memory(
     #   save as symmetric log, since the fluxes can be negative
     model_seds_with_bias = np.asfortranarray(_seds + ast_bias)
     # full_model_flux = np.sign(logtempseds) * np.log10(1 + np.abs(logtempseds * math.log(10)))
-    full_model_flux = (
-        np.sign(model_seds_with_bias)
-        * np.log1p(np.abs(model_seds_with_bias * math.log(10)))
-        / math.log(10)
-    )
+    full_model_flux = symlog(model_seds_with_bias)
 
     # setup the arrays to temp store the results
     n_qnames = len(qnames)
@@ -469,13 +487,18 @@ def Q_all_memory(
     for qname in qnames:
 
         # get bin properties
-        qname_vals, nbins, logspacing, minval, maxval = setup_param_bins(
+        qname_vals, nbins, logspacing, minval, maxval, uniqvals = setup_param_bins(
             qname, max_nbins, g0, full_model_flux, filters, grid_info_dict
         )
 
         # generate the fast 1d pdf mapping
         _tpdf1d = pdf1d(
-            qname_vals, nbins, logspacing=logspacing, minval=minval, maxval=maxval
+            qname_vals,
+            nbins,
+            logspacing=logspacing,
+            minval=minval,
+            maxval=maxval,
+            uniqvals=uniqvals,
         )
         fast_pdf1d_objs.append(_tpdf1d)
 
@@ -512,6 +535,7 @@ def Q_all_memory(
                 logspacing_p1,
                 minval_p1,
                 maxval_p1,
+                uniqvals_p1,
             ) = setup_param_bins(
                 qname_1, max_nbins, g0, full_model_flux, filters, grid_info_dict
             )
@@ -521,6 +545,7 @@ def Q_all_memory(
                 logspacing_p2,
                 minval_p2,
                 maxval_p2,
+                uniqvals_p2,
             ) = setup_param_bins(
                 qname_2, max_nbins, g0, full_model_flux, filters, grid_info_dict
             )
@@ -550,7 +575,7 @@ def Q_all_memory(
     #     fill the variables
     # also - find the start position for the resumed run
     if resume:
-        stats_table = Table.read(stats_outname)
+        stats_table = Table.read(stats_outname, hdu=1)
 
         for k, qname in enumerate(qnames):
             best_vals[:, k] = stats_table["{0:s}_Best".format(qname)]
@@ -763,6 +788,8 @@ def Q_all_memory(
                         total_log_norm,
                         qnames,
                         p,
+                        sedgrid.filters,
+                        sedgrid.lamb,
                     )
 
                 # save the lnps
@@ -796,6 +823,8 @@ def Q_all_memory(
             total_log_norm,
             qnames,
             p,
+            sedgrid.filters,
+            sedgrid.lamb,
         )
 
     # save the lnps
@@ -850,11 +879,11 @@ def IAU_names_and_extra_info(obsdata, surveyname="PHAT", extraInfo=False):
                 + c.ra.to_string(
                     unit=ap_units.hourangle,
                     sep="",
-                    precision=2,
+                    precision=4,
                     alwayssign=False,
                     pad=True,
                 )
-                + c.dec.to_string(sep="", precision=2, alwayssign=True, pad=True)
+                + c.dec.to_string(sep="", precision=3, alwayssign=True, pad=True)
             )
             r["Name"] = _tnames
 
@@ -870,7 +899,8 @@ def IAU_names_and_extra_info(obsdata, surveyname="PHAT", extraInfo=False):
 
     # include the observed filter fluxes
     for k, filtername in enumerate(obsdata.filters):
-        r[filtername] = (obsdata.data[filtername] * obsdata.vega_flux[k]).astype(float)
+        obsfiltname = obsdata.filter_aliases[filtername]
+        r[filtername] = (obsdata.data[obsfiltname] * obsdata.vega_flux[k]).astype(float)
 
     return r
 
@@ -880,11 +910,12 @@ def summary_table_memory(
     noisemodel,
     sedgrid,
     keys=None,
-    gridbackend="cache",
+    gridbackend="memory",
     threshold=-10,
     save_every_npts=None,
     lnp_npts=None,
     resume=False,
+    max_nbins=200,
     stats_outname=None,
     pdf1d_outname=None,
     pdf2d_outname=None,
@@ -921,6 +952,8 @@ def summary_table_memory(
     use_full_cov_matrix : bool
         set to use the full covariance matrix if it is present in the
         noise model file
+    max_nbins : int (default=200)
+        maxiumum number of bins to use for the 1D likelihood calculations
     stats_outname : str
         set to output the stats file into a FITS file with extensions
     pdf1d_outname : str
@@ -956,7 +989,7 @@ def summary_table_memory(
     """
 
     if type(sedgrid) == str:
-        g0 = grid.FileSEDGrid(sedgrid, backend=gridbackend)
+        g0 = grid.SEDGrid(sedgrid, backend=gridbackend)
     else:
         g0 = sedgrid
 
@@ -989,6 +1022,7 @@ def summary_table_memory(
         threshold=threshold,
         save_every_npts=save_every_npts,
         lnp_npts=lnp_npts,
+        max_nbins=max_nbins,
         stats_outname=stats_outname,
         pdf1d_outname=pdf1d_outname,
         pdf2d_outname=pdf2d_outname,
