@@ -1,4 +1,5 @@
-from beast.external.eztables.table import Table
+from astropy.table import Table
+# from beast.external.eztables.table import Table
 
 __all__ = ["NoiseModel"]
 
@@ -8,10 +9,11 @@ class NoiseModel(object):
 
     def __init__(self, astfile, *args, **kwargs):
         self.astfile = astfile
+        self.filter_aliases = {}
         self.load_data()
 
     def load_data(self):
-        self.data = Table(self.astfile)
+        self.data = Table.read(self.astfile)
 
     def fit(self, *args, **kwargs):
         raise NotImplementedError
