@@ -21,9 +21,11 @@ from astropy import units
 from tqdm import tqdm
 
 from beast.physicsmodel.stars import stellib
-from beast.physicsmodel.grid import SpectralGrid
-from beast.physicsmodel.prior_weights_dust import PriorWeightsDust
-from beast.external.eztables import Table
+from beast.physicsmodel.grid import SpectralGrid, SEDGrid
+from beast.physicsmodel.priormodel import PriorDustModel
+
+# from beast.external.eztables import Table
+from astropy.table import Table
 from beast.tools.helpers import generator
 from beast.tools import helpers
 
@@ -179,15 +181,15 @@ def apply_distance_grid(specgrid, distances, redshift=0):
 
     # Add distance column if multiple distances are specified
     cols = {}
-    cols["distance"] = np.empty(N, dtype=float)
+    cols["distance"] = np.zeros(N, dtype=float)
 
     # Existing columns
     keys0 = list(g0.keys())
     for key in keys0:
-        cols[key] = np.empty(N, dtype=float)
+        cols[key] = np.zeros(N, dtype=float)
 
     n_sed_points = g0.seds.shape[1]
-    new_seds = np.empty((N, n_sed_points), dtype=float)
+    new_seds = np.zeros((N, n_sed_points), dtype=float)
 
     for count, distance in enumerate(tqdm(_distances, desc="Distance grid")):
 
@@ -299,7 +301,7 @@ def make_extinguished_grid(
     if isinstance(spec_grid, str):
         ext = spec_grid.split(".")[-1]
         if ext in ["hdf", "hd5", "hdf5"]:
-            g0 = SpectralGrid(spec_grid, backend="hdf")
+            g0 = SpectralGrid(spec_grid, backend="disk")
         else:
             g0 = SpectralGrid(spec_grid, backend="cache")
     else:
@@ -320,10 +322,12 @@ def make_extinguished_grid(
     # ========================
     # basically the dot product from all input 1d vectors
     # setup interation over the full dust parameter grid
+
+    # setup the dust prior models
+    av_prior = PriorDustModel(av_prior_model)
+    rv_prior = PriorDustModel(rv_prior_model)
     if with_fA:
-        dustpriors = PriorWeightsDust(
-            avs, av_prior_model, rvs, rv_prior_model, fAs, fA_prior_model
-        )
+        fA_prior = PriorDustModel(fA_prior_model)
 
         it = np.nditer(np.ix_(avs, rvs, fAs))
         niter = np.size(avs) * np.size(rvs) * np.size(fAs)
@@ -342,10 +346,6 @@ def make_extinguished_grid(
         if npts == 0:
             raise AttributeError("No valid points")
     else:
-        dustpriors = PriorWeightsDust(
-            avs, av_prior_model, rvs, rv_prior_model, [1.0], fA_prior_model
-        )
-
         it = np.nditer(np.ix_(avs, rvs))
         npts = np.size(avs) * np.size(rvs)
         pts = ((float(ak), float(rk)) for ak, rk in it)
@@ -359,8 +359,9 @@ def make_extinguished_grid(
         print("Generating a final grid of {0:d} points".format(N))
     else:
         print(
-            "Generating a final grid of {0:d} points in {1:d}"
-            + " pieces".format(N, int(float(N0) / chunksize + 1.0))
+            "Generating a final grid of {0:d} points in {1:d} pieces".format(
+                N, int(float(N0) / chunksize + 1.0)
+            )
         )
 
     if chunksize <= 0:
@@ -373,28 +374,28 @@ def make_extinguished_grid(
         # iter over chunks of models
 
         # setup chunk outputs
-        cols = {"Av": np.empty(N, dtype=float), "Rv": np.empty(N, dtype=float)}
+        cols = {"Av": np.zeros(N, dtype=float), "Rv": np.zeros(N, dtype=float)}
 
         if with_fA:
-            cols["Rv_A"] = np.empty(N, dtype=float)
-            cols["f_A"] = np.empty(N, dtype=float)
+            cols["Rv_A"] = np.zeros(N, dtype=float)
+            cols["f_A"] = np.zeros(N, dtype=float)
 
         keys = list(g0.keys())
         for key in keys:
-            cols[key] = np.empty(N, dtype=float)
+            cols[key] = np.zeros(N, dtype=float)
 
         n_filters = len(filter_names)
-        _seds = np.empty((N, n_filters), dtype=float)
+        _seds = np.zeros((N, n_filters), dtype=float)
         if absflux_cov:
             n_offdiag = ((n_filters ** 2) - n_filters) / 2
-            _cov_diag = np.empty((N, n_filters), dtype=float)
-            _cov_offdiag = np.empty((N, n_offdiag), dtype=float)
+            _cov_diag = np.zeros((N, n_filters), dtype=float)
+            _cov_offdiag = np.zeros((N, n_offdiag), dtype=float)
 
         for count, pt in enumerate(tqdm(chunk_pts, desc="SED grid")):
 
             if with_fA:
                 Av, Rv, f_A = pt
-                dust_prior_weight = dustpriors.get_weight(Av, Rv, f_A)
+                dust_prior_weight = av_prior(Av) * rv_prior(Rv) * fA_prior(f_A)
                 Rv_MW = extLaw.get_Rv_A(Rv, f_A)
                 r = g0.applyExtinctionLaw(extLaw, Av=Av, Rv=Rv, f_A=f_A, inplace=False)
                 # add extra "spectral bands" if requested
@@ -414,7 +415,7 @@ def make_extinguished_grid(
 
             else:
                 Av, Rv = pt
-                dust_prior_weight = dustpriors.get_weight(Av, Rv, 1.0)
+                dust_prior_weight = av_prior(Av) * rv_prior(Rv)
                 r = g0.applyExtinctionLaw(extLaw, Av=Av, Rv=Rv, inplace=False)
 
                 if add_spectral_properties_kwargs is not None:
@@ -434,7 +435,7 @@ def make_extinguished_grid(
                 if key not in keys:
                     k1 = N0 * count
                     k2 = N0 * (count + 1)
-                    cols.setdefault(key, np.empty(N, dtype=float))[
+                    cols.setdefault(key, np.zeros(N, dtype=float))[
                         k1:k2
                     ] = temp_results.grid[key]
 
@@ -468,7 +469,7 @@ def make_extinguished_grid(
 
         # Ship
         if absflux_cov:
-            g = SpectralGrid(
+            g = SEDGrid(
                 _lamb,
                 seds=_seds,
                 cov_diag=_cov_diag,
@@ -477,9 +478,9 @@ def make_extinguished_grid(
                 backend="memory",
             )
         else:
-            g = SpectralGrid(_lamb, seds=_seds, grid=Table(cols), backend="memory")
+            g = SEDGrid(_lamb, seds=_seds, grid=Table(cols), backend="memory")
 
-        g.grid.header["filters"] = " ".join(filter_names)
+        g.header["filters"] = " ".join(filter_names)
 
         yield g
 
@@ -492,7 +493,8 @@ def add_spectral_properties(
     nameformat=None,
     filterLib=None,
 ):
-    """ Addon spectral calculations to spectral grids to extract in the fitting
+    """
+    Addon spectral calculations to spectral grids to extract in the fitting
     routines
 
     Parameters
@@ -537,7 +539,7 @@ def add_spectral_properties(
             logtempseds[indxs] = -100.0
 
         for i, fk in enumerate(filternames):
-            specgrid.grid.addCol("log" + nameformat.format(fk), logtempseds[:, i])
+            specgrid.grid["log" + nameformat.format(fk)] = logtempseds[:, i]
         del temp
 
     if filters is not None:
@@ -553,7 +555,7 @@ def add_spectral_properties(
             logtempseds[indxs] = -100.0
 
         for i, fk in enumerate(filters):
-            specgrid.grid.addCol("log" + nameformat.format(fk.name), logtempseds[:, i])
+            specgrid.grid["log" + nameformat.format(fk.name)] = logtempseds[:, i]
         del temp
 
     if callables is not None:
@@ -591,8 +593,8 @@ def calc_absflux_cov_matrices(specgrid, sedgrid, filter_names):
     n_models = specgrid.seds.shape[0]
     n_filters = len(filter_names)
     n_offdiag = ((n_filters ** 2) - n_filters) / 2
-    cov_diag = np.empty((n_models, n_filters), dtype=np.float64)
-    cov_offdiag = np.empty((n_models, n_offdiag), dtype=np.float64)
+    cov_diag = np.zeros((n_models, n_filters), dtype=np.float64)
+    cov_offdiag = np.zeros((n_models, n_offdiag), dtype=np.float64)
 
     # pack the resulting covariance matrices into diganonal and
     # non-diagnonal terms
@@ -605,9 +607,9 @@ def calc_absflux_cov_matrices(specgrid, sedgrid, filter_names):
     ] * np.square(sedgrid.seds[:, n_filters - 1])
     for k in range(n_filters - 1):
         cov_diag[:, k] = absflux_cov_mats[:, k, k] * np.square(sedgrid.seds[:, k])
-        for l in range(k + 1, n_filters):
+        for ll in range(k + 1, n_filters):
             cov_offdiag[:, m] = (
-                absflux_cov_mats[:, k, l] * sedgrid.seds[:, k] * sedgrid.seds[:, l]
+                absflux_cov_mats[:, k, ll] * sedgrid.seds[:, k] * sedgrid.seds[:, ll]
             )
             m += 1
 
