@@ -12,11 +12,11 @@ from scipy.interpolate import interp1d
 from numpy.lib import recfunctions
 from astropy import constants
 from tqdm import tqdm
+from matplotlib.path import Path
+from astropy.table import Table
 
 from beast.physicsmodel.grid import SpectralGrid
-from matplotlib.path import Path
-
-from beast.external.eztables import Table
+# from beast.external.eztables import Table
 from beast.config import __ROOT__, __NTHREADS__
 from beast.physicsmodel.stars.include import __interp__
 from beast.tools.helpers import nbytes
@@ -290,7 +290,7 @@ class Stellib(object):
 
     def __init__(self, *args, **kargs):
         """ Contructor """
-        pass
+        self.header = {}
 
     def _load_(self):
         raise NotImplementedError
@@ -633,7 +633,7 @@ class Stellib(object):
         # SEDs are kept into a ndarray
         ndata = len(pts)
         _grid = {}
-        _grid["radius"] = np.empty(ndata, dtype=float)
+        _grid["radius"] = np.zeros(ndata, dtype=float)
 
         # stores the grid+prior weights (initialize to 1)
         _grid["weight"] = np.full(ndata, 1.0, dtype=float)
@@ -653,7 +653,7 @@ class Stellib(object):
         #   to the SED grid
         _grid["specgrid_indx"] = np.full(ndata, 0.0, dtype=float)
 
-        specs = np.empty((ndata, len(self.wavelength)), dtype=float)
+        specs = np.zeros((ndata, len(self.wavelength)), dtype=float)
 
         # copy meta data of pts into the resulting structure
         if hasattr(pts, "keys"):
@@ -1222,7 +1222,6 @@ class CompositeStellib(Stellib):
             _pts = {}
             # oslk + 1 since 0 corresponds to "not covered by any osl"
             ind = osl_index == (oslk + 1)
-            # print sum(ind)
             if np.sum(ind) > 0:
                 if hasattr(pts, "keys"):
                     keys = list(pts.keys())
@@ -1297,7 +1296,7 @@ class Elodie(Stellib):
         g = SpectralGrid(self.source, backend="memory")
         self.wavelength = g.lamb
         self.grid = g.grid
-        self.grid.header["NAME"] = self.name
+        self.header["NAME"] = self.name
         self.spectra = g.seds
 
     def bbox(self, dlogT=0.05, dlogg=0.25):
@@ -1396,7 +1395,6 @@ class BaSeL(Stellib):
     References
     ----------
     * Lejeune, Cuisiner, and Buser, 1998 A&AS, 130, 65
-    * can be downloaded http://www.astro.unibas.ch/BaSeL_files/BaSeL2_2.tar.gz
     """
 
     def __init__(self, *args, **kwargs):
@@ -1409,7 +1407,7 @@ class BaSeL(Stellib):
         g = SpectralGrid(self.source, backend="memory")
         self.wavelength = g.lamb
         self.grid = g.grid
-        self.grid.header["NAME"] = "Basel 2.2 (pegase)"
+        self.header["NAME"] = "Basel 2.2 (pegase)"
         self.spectra = g.seds
 
     def bbox(self, dlogT=0.05, dlogg=0.25):
@@ -1520,7 +1518,7 @@ class Kurucz(Stellib):
         g = SpectralGrid(self.source, backend="memory")
         self.wavelength = g.lamb
         self.grid = g.grid
-        self.grid.header["NAME"] = self.name
+        self.header["NAME"] = self.name
         self.spectra = g.seds
 
     def bbox(self, dlogT=0.05, dlogg=0.25):
@@ -1600,10 +1598,9 @@ class Tlusty(Stellib):
     * **BSTAR2006 Grid**: Early B-type stars, 15000 K <= Teff <= 30000 K
             * Reference: Lanz & Hubeny (2007)
 
-    files are available at: http://nova.astro.umd.edu/Tlusty2002/database/
+    files are available at: http://tlusty.oca.eu/
 
     O and B stars rebinned to nearly 20,000 frequency points (for CLOUDY usage)
-    http://nova.astro.umd.edu/Tlusty2002/database/obstar_merged_3d.ascii.gz
     """
 
     def __init__(self, filename=None, *args, **kwargs):
@@ -1619,7 +1616,7 @@ class Tlusty(Stellib):
         g = SpectralGrid(self.source, backend="memory")
         self.wavelength = g.lamb
         self.grid = g.grid
-        self.grid.header["NAME"] = "tlusty"
+        self.header["NAME"] = "tlusty"
         self.spectra = g.seds
 
     def bbox(self, dlogT=0.05, dlogg=0.25):
@@ -1688,7 +1685,7 @@ class BTSettl(Stellib):
       http://adsabs.harvard.edu/abs/2016sf2a.conf..223A
       http://adsabs.harvard.edu/abs/2012RSPTA.370.2765A
 
-    Files available at: https://phoenix.ens-lyon.fr/Grids/BT-Settl/
+    Files used to be available at: (https)phoenix.ens-lyon.fr/Grids/BT-Settl/
 
     Current Library: AGSS2009 Abundances (due to grid availability)
     Spectra rebinned to match Kurucz, and custom 2 Ang medium resolution
@@ -1707,7 +1704,7 @@ class BTSettl(Stellib):
         g = SpectralGrid(self.source, backend="memory")
         self.wavelength = g.lamb
         self.grid = g.grid
-        self.grid.header["NAME"] = self.name
+        self.header["NAME"] = self.name
         self.spectra = g.seds
 
     def bbox(self, dlogT=0.05, dlogg=0.25):
@@ -1783,7 +1780,7 @@ class Munari(Stellib):
     Paper: Munari et al. 2005 A&A 442 1127
     http://adsabs.harvard.edu/abs/2005A%26A...442.1127M
 
-    Files available at: http://archives.pd.astro.it/2500-10500/
+    Files available at: https://vizier.u-strasbg.fr/viz-bin/VizieR-3?-source=J/A%2bA/442/1127
     """
 
     def __init__(self, *args, **kwargs):
@@ -1796,7 +1793,7 @@ class Munari(Stellib):
         g = SpectralGrid(self.source, backend="memory")
         self.wavelength = g.lamb
         self.grid = g.grid
-        self.grid.header["NAME"] = self.name
+        self.header["NAME"] = self.name
         self.spectra = g.seds
 
     def bbox(self, dlogT=0.05, dlogg=0.25):
@@ -1868,7 +1865,7 @@ class Aringer(Stellib):
     Paper 2019: https://ui.adsabs.harvard.edu/abs/2019MNRAS.487.2133A/abstract
 
     Files available at:
-    http://starkey.astro.unipd.it/atm/
+    http://starkey.astro.unipd.it/Cstar_atmos_models.html
 
     """
 
@@ -1882,7 +1879,7 @@ class Aringer(Stellib):
         g = SpectralGrid(self.source, backend="memory")
         self.wavelength = g.lamb
         self.grid = g.grid
-        self.grid.header["NAME"] = self.name
+        self.header["NAME"] = self.name
         self.spectra = g.seds
 
     def bbox(self, dlogT=0.05, dlogg=0.25):
