@@ -1,4 +1,3 @@
-import math
 import os
 import re
 from multiprocessing import Pool
@@ -10,11 +9,13 @@ from astropy.io import fits
 from astropy.table import Table
 
 from beast.observationmodel.noisemodel.generic_noisemodel import get_noisemodelcat
-from beast.physicsmodel import grid
-from beast.external import eztables
+from beast.physicsmodel.grid import SEDGrid
+
+# from beast.external import eztables
 from beast.fitting.fit import save_pdf1d
 from beast.fitting.fit_metrics import percentile
 from beast.tools import read_beast_data
+from beast.tools.symlog import symlog
 
 
 def uniform_slices(num_points, num_slices):
@@ -48,7 +49,7 @@ def split_grid(grid_fname, num_subgrids, overwrite=False):
     num_subgrids: integer
         the number of parts the grid should be split into
 
-    overwrite: boolean
+    overwrite: bool
         any subgrids that already exist will be deleted if set to True.
         If set to False, skip over any grids that are already there.
 
@@ -56,10 +57,9 @@ def split_grid(grid_fname, num_subgrids, overwrite=False):
     -------
     list of string
         the names of the newly created subgrid files
-
     """
 
-    g = grid.FileSEDGrid(grid_fname, backend="hdf")
+    g = SEDGrid(grid_fname, backend="disk")
 
     fnames = []
 
@@ -78,18 +78,15 @@ def split_grid(grid_fname, num_subgrids, overwrite=False):
 
         print("constructing subgrid " + str(i))
 
-        # Load a slice as a SpectralGrid object
-        sub_g = grid.SpectralGrid(
-            g.lamb[:],
-            seds=g.seds[slc],
-            grid=eztables.Table(g.grid[slc]),
-            backend="memory",
+        # Load a slice as a SEDGrid object
+        sub_g = SEDGrid(
+            g.lamb[:], seds=g.seds[slc], grid=Table(g.grid[slc]), backend="memory",
         )
         if g.filters is not None:
-            sub_g.grid.header["filters"] = " ".join(g.filters)
+            sub_g.header["filters"] = " ".join(g.filters)
 
         # Save it to a new file
-        sub_g.writeHDF(subgrid_fname, append=False)
+        sub_g.write(subgrid_fname, append=False)
 
     return fnames
 
@@ -111,8 +108,8 @@ def merge_grids(seds_fname, sub_names):
     if not os.path.isfile(seds_fname):
         for n in sub_names:
             print("Appending {} to {}".format(n, seds_fname))
-            g = grid.FileSEDGrid(n)
-            g.writeHDF(seds_fname, append=True)
+            g = SEDGrid(n)
+            g.write(seds_fname, append=True)
     else:
         print("{} already exists".format(seds_fname))
 
@@ -138,8 +135,8 @@ def subgrid_info(grid_fname, noise_fname=None):
         {name of quantity [string]: {'min': min, 'max': max, 'unique': unique values}}
     """
 
-    # Use the HDFStore (pytables) backend
-    sedgrid = grid.FileSEDGrid(grid_fname, backend="hdf")
+    # Use the disk backend to minimize the memory usage
+    sedgrid = SEDGrid(grid_fname, backend="disk")
     seds = sedgrid.seds
 
     info_dict = {}
@@ -161,13 +158,8 @@ def subgrid_info(grid_fname, noise_fname=None):
         # The following is also in fit.py, so we're kind of doing double
         # work here, but it's necessary if we want to know the proper
         # ranges for these values.
-        full_model_flux = seds[:] + noisemodel["bias"]
-        logtempseds = np.array(full_model_flux)
-        full_model_flux = (
-            np.sign(logtempseds)
-            * np.log1p(np.abs(logtempseds * math.log(10)))
-            / math.log(10)
-        )
+        lin_full_model_flux = seds[:] + noisemodel["bias"]
+        full_model_flux = symlog(lin_full_model_flux)
 
         filters = sedgrid.filters
         for i, f in enumerate(filters):
@@ -273,13 +265,18 @@ def reduce_grid_info(grid_fnames, noise_fnames=None, nprocs=1, cap_unique=1000):
             "min": union_min[q],
             "max": union_max[q],
             "num_unique": len(union_unique[q]),
+            "unique_vals": union_unique[q],
         }
 
     return result_dict
 
 
 def merge_pdf1d_stats(
-    subgrid_pdf1d_fnames, subgrid_stats_fnames, re_run=False, output_fname_base=None
+    subgrid_pdf1d_fnames,
+    subgrid_stats_fnames,
+    re_run=False,
+    output_fname_base=None,
+    partial=False,
 ):
     """
     Merge a set of 1d pdfs that were generated by fits on different
@@ -351,7 +348,11 @@ def merge_pdf1d_stats(
         qnames = [hdu.name for hdu in hdul_0[1:]]
         nbins = {q: hdul_0[q].data.shape[1] for q in qnames}
         bincenters = {q: hdul_0[q].data[-1, :] for q in qnames}
-        nobs = hdul_0[qnames[0]].data.shape[0] - 1
+        if not partial:
+            nobs = hdul_0[qnames[0]].data.shape[0] - 1
+        else:
+            tot_prob = np.sum(hdul_0["M_ini"].data, axis=1)
+            nobs = len(np.where(tot_prob > 0.0)[0]) - 1
 
         # Check the following bin parameters for each of the other
         # subgrids
@@ -363,9 +364,15 @@ def merge_pdf1d_stats(
                     # the number of bins
                     if not pdf1d_0.shape[1] == pdf1d.shape[1]:
                         raise AssertionError()
-                    # the number of stars + 1
-                    if not pdf1d_0.shape[0] == pdf1d.shape[0]:
-                        raise AssertionError()
+                    # if partial is False, confirm number of stars + 1
+                    if not partial:
+                        if not pdf1d_0.shape[0] == pdf1d.shape[0]:
+                            raise AssertionError()
+                    # otherwise, update nobs to be smaller if needed
+                    else:
+                        tot_prob = np.sum(hdul["M_ini"].data, axis=1)
+                        current_nobs = len(np.where(tot_prob > 0.0)[0]) - 1
+                        nobs = np.min([nobs, current_nobs])
                     # the bin centers (stored in the last row of the
                     # image) should be equal (or both nan)
                     if not (
@@ -376,13 +383,17 @@ def merge_pdf1d_stats(
                         raise AssertionError()
 
     # Load all the stats files
-    stats = [Table.read(f) for f in subgrid_stats_fnames]
+    stats = [Table.read(f, hdu=1) for f in subgrid_stats_fnames]
+    try:
+        filters_tab = Table.read(subgrid_stats_fnames[0], hdu=2)
+    except ValueError:
+        filters_tab = None
 
     # First, let's read the arrays of weights (each subgrid has an array
     # of weights, containing one weight for each source).
     logweight = np.zeros((nobs, nsubgrids))
     for i, s in enumerate(stats):
-        logweight[:, i] = s["total_log_norm"]
+        logweight[:, i] = s["total_log_norm"][:nobs]
 
     # Best grid for each star (take max along grid axis)
     maxweight_index_per_star = np.argmax(logweight, axis=1)
@@ -410,7 +421,7 @@ def merge_pdf1d_stats(
     for g, pdf1d_f in enumerate(subgrid_pdf1d_fnames):
         with fits.open(pdf1d_f) as hdul:
             for i, q in enumerate(qnames):
-                pdf1d_g = hdul[q].data[:-1, :]
+                pdf1d_g = hdul[q].data[:nobs, :]
                 weight_column = weight[:, [g]]  # use [g] to keep dimension
                 save_pdf1d_vals[i][:-1, :] += pdf1d_g * weight_column
 
@@ -432,7 +443,7 @@ def merge_pdf1d_stats(
     # Grid with highest Pmax, for each star
     pmaxes = np.zeros((nobs, nsubgrids))
     for gridnr in range(nsubgrids):
-        pmaxes[:, gridnr] = stats[gridnr]["Pmax"]
+        pmaxes[:, gridnr] = stats[gridnr]["Pmax"][:nobs]
     max_pmax_index_per_star = pmaxes.argmax(axis=1)
 
     # Rebuild the stats
@@ -454,7 +465,7 @@ def merge_pdf1d_stats(
             total_weight_per_star = np.zeros(nobs)
             for gridnr, s in enumerate(stats):
                 grid_weight_per_star = weight[:, gridnr]
-                stats_dict[col] += stats[gridnr][col] * grid_weight_per_star
+                stats_dict[col] += stats[gridnr][col][:nobs] * grid_weight_per_star
                 total_weight_per_star += grid_weight_per_star
             stats_dict[col] /= total_weight_per_star
 
@@ -483,15 +494,22 @@ def merge_pdf1d_stats(
             # Take the lowest chi2 over all the grids
             all_chi2s = np.zeros((nobs, nsubgrids))
             for gridnr, s in enumerate(stats):
-                all_chi2s[:, gridnr] = s[col]
+                all_chi2s[:, gridnr] = s[col][:nobs]
             stats_dict[col] = np.amin(all_chi2s, axis=1)
 
         elif col == "Pmax":
             all_pmaxs = np.zeros((nobs, nsubgrids))
             for gridnr, s in enumerate(stats):
-                all_pmaxs[:, gridnr] = s[col]
+                all_pmaxs[:, gridnr] = s[col][:nobs]
             stats_dict[col] = np.amax(all_pmaxs, axis=1)
 
+        elif col == "Pmax_indx":
+            # index of the Pmax (to be useful, must be combined with best_gridsub_tag)
+            all_pmax_ind = np.zeros((nobs, nsubgrids), dtype=int)
+            for gridnr, s in enumerate(stats):
+                all_pmax_ind[:, gridnr] = s[col][:nobs]
+            stats_dict[col] = all_pmax_ind[np.arange(nobs), max_pmax_index_per_star]
+
         elif col == "total_log_norm":
             stats_dict[col] = np.log(weight.sum(axis=1)) + max_logweight
 
@@ -502,15 +520,18 @@ def merge_pdf1d_stats(
         # this. Actually specgrid_indx might make sense, since in my
         # particular case I'm splitting after the spec grid has been
         # created. Still leaving this out though.
-        elif (
-            not col == "chi2min_indx"
-            and not col == "Pmax_indx"
-            and not col == "specgrid_indx"
-        ):
-            stats_dict[col] = stats[0][col]
+        elif not col == "chi2min_indx" and not col == "specgrid_indx":
+            stats_dict[col] = stats[0][col][:nobs]
 
-    summary_tab = Table(stats_dict)
-    summary_tab.write(stats_fname, overwrite=True)
+    # also save the highest Pmax grid number
+    stats_dict["best_gridsub_tag"] = max_pmax_index_per_star
+
+    # save table to a file
+    ohdu = fits.HDUList()
+    ohdu.append(fits.table_to_hdu(Table(stats_dict)))
+    if filters_tab is not None:
+        ohdu.append(fits.table_to_hdu(filters_tab))
+    ohdu.writeto(stats_fname, overwrite=True)
 
     print("Saved combined 1dpdfs in " + pdf1d_fname)
     print("Saved combined stats in " + stats_fname)
@@ -519,10 +540,7 @@ def merge_pdf1d_stats(
 
 
 def merge_lnp(
-    subgrid_lnp_fnames,
-    re_run=False,
-    output_fname_base=None,
-    threshold=None,
+    subgrid_lnp_fnames, re_run=False, output_fname_base=None, threshold=None,
 ):
     """
     Merge a set of sparsely sampled log likelihood (lnp) files.  It is assumed
@@ -554,16 +572,15 @@ def merge_lnp(
 
     # create filename
     if output_fname_base is None:
-        merged_lnp_fname = "combined_lnp.fits"
+        merged_lnp_fname = "combined_lnp.hd5"
     else:
-        merged_lnp_fname = output_fname_base + "_lnp.fits"
+        merged_lnp_fname = output_fname_base + "_lnp.hd5"
 
     # check if we need to rerun
     if os.path.isfile(merged_lnp_fname) and (re_run is False):
         print(str(len(subgrid_lnp_fnames)) + " files already merged, skipping")
         return merged_lnp_fname
 
-
     # dictionaries to compile all the info
     merged_lnp = defaultdict(list)
     merged_subgrid = defaultdict(list)
@@ -572,18 +589,19 @@ def merge_lnp(
     for fname in subgrid_lnp_fnames:
 
         # extract subgrid number from filename
-        subgrid_num = [i for i in fname.split('_') if 'gridsub' in i][0][7:]
+        subgrid_num = [i for i in fname.split("_") if "gridsub" in i][0][7:]
 
         # read in the SED indices and lnP values
         lnp_data = read_beast_data.read_lnp_data(fname, shift_lnp=False)
-        n_lnp, n_star = lnp_data['vals'].shape
+        n_lnp, n_star = lnp_data["vals"].shape
 
         # save each star's values into the master dictionary
         for i in range(n_star):
-            merged_lnp['star_'+str(i)] += lnp_data['vals'][:,i].tolist()
-            merged_idx['star_'+str(i)] += lnp_data['indxs'][:,i].tolist()
-            merged_subgrid['star_'+str(i)] += np.full(n_lnp, int(subgrid_num)).tolist()
-
+            merged_lnp["star_" + str(i)] += lnp_data["vals"][:, i].tolist()
+            merged_idx["star_" + str(i)] += lnp_data["indxs"][:, i].tolist()
+            merged_subgrid["star_" + str(i)] += np.full(
+                n_lnp, int(subgrid_num)
+            ).tolist()
 
     # go through each star and remove values that are too small
     if threshold is not None:
@@ -594,17 +612,19 @@ def merge_lnp(
         # go through each star
         for i in range(n_star):
 
-            star_label = "star_"+str(i)
+            star_label = "star_" + str(i)
             # good indices
             keep_ind = np.where(
-                np.array(merged_lnp[star_label]) >
-                (max(merged_lnp[star_label]) - threshold)
+                (np.array(merged_lnp[star_label]) - max(merged_lnp[star_label]))
+                > threshold
             )[0]
             good_list_len[i] = len(keep_ind)
             # save just those
             merged_lnp[star_label] = np.array(merged_lnp[star_label])[keep_ind].tolist()
             merged_idx[star_label] = np.array(merged_idx[star_label])[keep_ind].tolist()
-            merged_subgrid[star_label] = np.array(merged_subgrid[star_label])[keep_ind].tolist()
+            merged_subgrid[star_label] = np.array(merged_subgrid[star_label])[
+                keep_ind
+            ].tolist()
 
         # figure out how many padded -inf/nan values need to be appended to make
         # each list the same length
@@ -614,24 +634,25 @@ def merge_lnp(
         # no list padding if there's no trimming for threshold
         n_list_pad = np.zeros(n_star)
 
-
     # write out the things in a new file
     with tables.open_file(merged_lnp_fname, "w") as out_table:
         for i in range(n_star):
-            star_label = "star_"+str(i)
-            star_group = out_table.create_group(star_label)
-            star_group.create_dataset(
-                'idx',
-                data=np.array(merged_idx[star_label] + n_list_pad*[np.nan])
+            star_label = "star_" + str(i)
+            star_group = out_table.create_group("/", star_label, title=star_label)
+            out_table.create_array(
+                star_group,
+                "idx",
+                np.array(merged_idx[star_label] + int(n_list_pad[i]) * [np.nan]),
             )
-            star_group.create_dataset(
-                'lnp',
-                data=np.array(merged_lnp[star_label] + n_list_pad*[-np.inf])
+            out_table.create_array(
+                star_group,
+                "lnp",
+                np.array(merged_lnp[star_label] + int(n_list_pad[i]) * [-np.inf]),
             )
-            star_group.create_dataset(
-                'subgrid',
-                data=np.array(merged_subgrid[star_label] + n_list_pad*[np.nan])
+            out_table.create_array(
+                star_group,
+                "subgrid",
+                np.array(merged_subgrid[star_label] + int(n_list_pad[i]) * [np.nan]),
             )
 
-
     return merged_lnp_fname
